@@ -2,8 +2,14 @@
 // Smilers! :)
 //
 
+#![feature(io_safety)]
+
 pub mod utils;
 pub mod models;
+pub extern crate md5;
+
+#[cfg(feature = "ddreplay")]
+pub mod ddreplay;
 
 #[cfg(feature = "memory")]
 pub mod memory;
